@@ -385,10 +385,8 @@ class GitTagMirror(SourceFetcher):
 
             if exit_code == 128:
                 self.source.info("Unable to find tag for specified branch name '{}'".format(tracking))
-                _, output = self.source.check_output(
-                        [self.source.host_git, 'rev-parse', tracking],
-                        fail="Unable to find commit for specified branch name '{}'".format(tracking),
-                        cwd=self.mirror)
+                return None, None
+
             tracking = output.rstrip('\n')
 
         else:
@@ -655,9 +653,11 @@ class AbstractGitTagSource(Source):
                        branch, track_tags=self.track_tags, track_args=track_args)
                        for branch in branches])
 
+            candidates.pop(None, None)
+
             # Find latest candidate ref from all branches
             # Update self.mirror.ref, node.ref
-            ret = max(candidates, key=candidates.get)
+            ret = max(candidates, key=candidates.get, default=None)
 
         return ret
 
@@ -757,9 +757,11 @@ class GitTagSource(AbstractGitTagSource):
                        branch, track_tags=self.track_tags, track_args=track_args)
                        for branch in branches])
 
+            candidates.pop(None, None)
+
             # Find latest candidate ref from all branches
             # Update self.mirror.ref, node.ref
-            ret = max(candidates, key=candidates.get)
+            ret = max(candidates, key=candidates.get, default=None)
 
         return ret
 
